package sun.launcher;

import java.math.RoundingMode;
import java.math.BigDecimal;
import java.util.ResourceBundle;
import sun.misc.VM;
import java.nio.file.DirectoryStream;
import java.nio.file.Path;
import java.nio.file.Files;
import java.util.List;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.text.Normalizer;
import java.util.jar.Manifest;
import java.io.IOException;
import java.util.jar.Attributes;
import java.util.jar.JarFile;
import java.io.File;
import java.text.MessageFormat;
import jdk.internal.platform.Metrics;
import jdk.internal.platform.Container;
import java.util.TreeSet;
import java.util.Locale;
import java.util.Iterator;
import java.util.Properties;
import java.util.Collections;
import java.util.ArrayList;
import java.io.PrintStream;

public enum LauncherHelper
{
    INSTANCE;
    
    private static final String MAIN_CLASS = "Main-Class";
    private static StringBuilder outBuf;
    private static final String INDENT = "    ";
    private static final String VM_SETTINGS = "VM settings:";
    private static final String PROP_SETTINGS = "Property settings:";
    private static final String LOCALE_SETTINGS = "Locale settings:";
    private static final String diagprop = "sun.java.launcher.diag";
    static final boolean trace;
    private static final String defaultBundleName = "sun.launcher.resources.launcher";
    private static PrintStream ostream;
    private static final ClassLoader scloader;
    private static Class<?> appClass;
    private static final int LM_UNKNOWN = 0;
    private static final int LM_CLASS = 1;
    private static final int LM_JAR = 2;
    private static final String encprop = "sun.jnu.encoding";
    private static String encoding;
    private static boolean isCharsetSupported;
    
    static void showSettings(boolean b, String s, long n, long n2, long n3, boolean b2) {
        initOutput(b);
        String[] split = s.split(":");
        String s2 = ((split.length > 1 && split[1] != null) ? split[1].trim() : "all");
        int n4 = -1;
        switch (s2.hashCode()) {
            case 3767: {
                if (s2.equals("vm")) {
                    n4 = 0;
                    break;
                }
                break;
            }
            case -926053069: {
                if (s2.equals("properties")) {
                    n4 = 1;
                    break;
                }
                break;
            }
            case -1097462182: {
                if (s2.equals("locale")) {
                    n4 = 2;
                    break;
                }
                break;
            }
            case -887328209: {
                if (s2.equals("system")) {
                    n4 = 3;
                    break;
                }
                break;
            }
        }
        switch (n4) {
            case 0: {
                printVmSettings(n, n2, n3, b2);
                return;
            }
            case 1: {
                printProperties();
                return;
            }
            case 2: {
                printLocale();
                return;
            }
            case 3: {
                if (System.getProperty("os.name").contains("Linux")) {
                    printSystemMetrics();
                    return;
                }
                break;
            }
        }
        printVmSettings(n, n2, n3, b2);
        printProperties();
        printLocale();
        if (System.getProperty("os.name").contains("Linux")) {
            printSystemMetrics();
        }
    }
    
    private static void printVmSettings(long n, long n2, long n3, boolean b) {
        LauncherHelper.ostream.println("VM settings:");
        if (n3 != 0L) {
            LauncherHelper.ostream.println("    Stack Size: " + LauncherHelper.SizePrefix.scaleValue(n3));
        }
        if (n != 0L) {
            LauncherHelper.ostream.println("    Min. Heap Size: " + LauncherHelper.SizePrefix.scaleValue(n));
        }
        if (n2 != 0L) {
            LauncherHelper.ostream.println("    Max. Heap Size: " + LauncherHelper.SizePrefix.scaleValue(n2));
        }
        else {
            LauncherHelper.ostream.println("    Max. Heap Size (Estimated): " + LauncherHelper.SizePrefix.scaleValue(Runtime.getRuntime().maxMemory()));
        }
        LauncherHelper.ostream.println("    Ergonomics Machine Class: " + (b ? "server" : "client"));
        LauncherHelper.ostream.println("    Using VM: " + System.getProperty("java.vm.name"));
        LauncherHelper.ostream.println();
    }
    
    private static void printProperties() {
        Properties properties = System.getProperties();
        LauncherHelper.ostream.println("Property settings:");
        ArrayList<Comparable> list = new ArrayList();
        list.addAll(properties.stringPropertyNames());
        Collections.sort(list);
        for (String key : list) {
            printPropertyValue(key, properties.getProperty(key));
        }
        LauncherHelper.ostream.println();
    }
    
    private static boolean isPath(String s) {
        return s.endsWith(".dirs") || s.endsWith(".path");
    }
    
    private static void printPropertyValue(String str, String x) {
        LauncherHelper.ostream.print("    " + str + " = ");
        if (str.equals("line.separator")) {
            for (int n2 : x.getBytes()) {
                switch (n2) {
                    case 13: {
                        LauncherHelper.ostream.print("\\r ");
                        break;
                    }
                    case 10: {
                        LauncherHelper.ostream.print("\\n ");
                        break;
                    }
                    default: {
                        LauncherHelper.ostream.printf("0x%02X", new Object[] { Integer.valueOf(n2 & 0xFF) });
                        break;
                    }
                }
            }
            LauncherHelper.ostream.println();
            return;
        }
        if (!isPath(str)) {
            LauncherHelper.ostream.println(x);
            return;
        }
        String[] split = x.split(System.getProperty("path.separator"));
        int n = 1;
        for (String s : split) {
            if (n != 0) {
                LauncherHelper.ostream.println(s);
                n = 0;
            }
            else {
                LauncherHelper.ostream.println("        " + s);
            }
        }
        return;
    }
    
    private static void printLocale() {
        Locale default1 = Locale.getDefault();
        LauncherHelper.ostream.println("Locale settings:");
        LauncherHelper.ostream.println("    default locale = " + default1.getDisplayLanguage());
        LauncherHelper.ostream.println("    default display locale = " + Locale.getDefault(Locale.Category.DISPLAY).getDisplayName());
        LauncherHelper.ostream.println("    default format locale = " + Locale.getDefault(Locale.Category.FORMAT).getDisplayName());
        printLocales();
        LauncherHelper.ostream.println();
    }
    
    private static void printLocales() {
        Locale[] availableLocales = Locale.getAvailableLocales();
        int n = (availableLocales == null) ? 0 : availableLocales.length;
        if (n < 1) {
            return;
        }
        TreeSet<String> set = new TreeSet();
        for (int length = availableLocales.length, i = 0; i < length; ++i) {
            set.add(availableLocales[i].toString());
        }
        LauncherHelper.ostream.print("    available locales = ");
        Iterator<Object> iterator = set.iterator();
        int n2 = n - 1;
        for (int n3 = 0; iterator.hasNext(); ++n3) {
            LauncherHelper.ostream.print((String)iterator.next());
            if (n3 != n2) {
                LauncherHelper.ostream.print(", ");
            }
            if ((n3 + 1) % 8 == 0) {
                LauncherHelper.ostream.println();
                LauncherHelper.ostream.print("        ");
            }
        }
        return;
    }
    
    public static void printSystemMetrics() {
        Metrics metrics = Container.metrics();
        LauncherHelper.ostream.println("Operating System Metrics:");
        if (metrics == null) {
            LauncherHelper.ostream.println("    No metrics available for this platform");
            return;
        }
        LauncherHelper.ostream.println("    Provider: " + metrics.getProvider());
        LauncherHelper.ostream.println("    Effective CPU Count: " + metrics.getEffectiveCpuCount());
        LauncherHelper.ostream.println("    CPU Period: " + metrics.getCpuPeriod() + ((metrics.getCpuPeriod() == -1L) ? "" : "us"));
        LauncherHelper.ostream.println("    CPU Quota: " + metrics.getCpuQuota() + ((metrics.getCpuQuota() == -1L) ? "" : "us"));
        LauncherHelper.ostream.println("    CPU Shares: " + metrics.getCpuShares());
        int[] cpuSetCpus = metrics.getCpuSetCpus();
        LauncherHelper.ostream.println("    List of Processors, " + cpuSetCpus.length + " total: ");
        LauncherHelper.ostream.print("    ");
        for (int i = 0; i < cpuSetCpus.length; ++i) {
            LauncherHelper.ostream.print(cpuSetCpus[i] + " ");
        }
        if (cpuSetCpus.length > 0) {
            LauncherHelper.ostream.println("");
        }
        int[] effectiveCpuSetCpus = metrics.getEffectiveCpuSetCpus();
        LauncherHelper.ostream.println("    List of Effective Processors, " + effectiveCpuSetCpus.length + " total: ");
        LauncherHelper.ostream.print("    ");
        for (int j = 0; j < effectiveCpuSetCpus.length; ++j) {
            LauncherHelper.ostream.print(effectiveCpuSetCpus[j] + " ");
        }
        if (effectiveCpuSetCpus.length > 0) {
            LauncherHelper.ostream.println("");
        }
        int[] cpuSetMems = metrics.getCpuSetMems();
        LauncherHelper.ostream.println("    List of Memory Nodes, " + cpuSetMems.length + " total: ");
        LauncherHelper.ostream.print("    ");
        for (int k = 0; k < cpuSetMems.length; ++k) {
            LauncherHelper.ostream.print(cpuSetMems[k] + " ");
        }
        if (cpuSetMems.length > 0) {
            LauncherHelper.ostream.println("");
        }
        int[] effectiveCpuSetMems = metrics.getEffectiveCpuSetMems();
        LauncherHelper.ostream.println("    List of Available Memory Nodes, " + effectiveCpuSetMems.length + " total: ");
        LauncherHelper.ostream.print("    ");
        for (int l = 0; l < effectiveCpuSetMems.length; ++l) {
            LauncherHelper.ostream.print(effectiveCpuSetMems[l] + " ");
        }
        if (effectiveCpuSetMems.length > 0) {
            LauncherHelper.ostream.println("");
        }
        LauncherHelper.ostream.println("    CPUSet Memory Pressure Enabled: " + metrics.isCpuSetMemoryPressureEnabled());
        long memoryLimit = metrics.getMemoryLimit();
        LauncherHelper.ostream.println("    Memory Limit: " + ((memoryLimit >= 0L) ? LauncherHelper.SizePrefix.scaleValue(memoryLimit) : "Unlimited"));
        long memorySoftLimit = metrics.getMemorySoftLimit();
        LauncherHelper.ostream.println("    Memory Soft Limit: " + ((memorySoftLimit >= 0L) ? LauncherHelper.SizePrefix.scaleValue(memorySoftLimit) : "Unlimited"));
        long memoryAndSwapLimit = metrics.getMemoryAndSwapLimit();
        LauncherHelper.ostream.println("    Memory & Swap Limit: " + ((memoryAndSwapLimit >= 0L) ? LauncherHelper.SizePrefix.scaleValue(memoryAndSwapLimit) : "Unlimited"));
        long kernelMemoryLimit = metrics.getKernelMemoryLimit();
        LauncherHelper.ostream.println("    Kernel Memory Limit: " + ((kernelMemoryLimit >= 0L) ? LauncherHelper.SizePrefix.scaleValue(kernelMemoryLimit) : "Unlimited"));
        long tcpMemoryLimit = metrics.getTcpMemoryLimit();
        LauncherHelper.ostream.println("    TCP Memory Limit: " + ((tcpMemoryLimit >= 0L) ? LauncherHelper.SizePrefix.scaleValue(tcpMemoryLimit) : "Unlimited"));
        LauncherHelper.ostream.println("    Out Of Memory Killer Enabled: " + metrics.isMemoryOOMKillEnabled());
        LauncherHelper.ostream.println("");
        return;
    }
    
    private static String getLocalizedMessage(String key, Object... arguments) {
        String string = LauncherHelper.ResourceBundleHolder.RB.getString(key);
        return (arguments != null) ? MessageFormat.format(string, arguments) : string;
    }
    
    static void initHelpMessage(String s) {
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.header", new Object[] { (s == null) ? "java" : s }));
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.datamodel", new Object[] { Integer.valueOf(32) }));
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.datamodel", new Object[] { Integer.valueOf(64) }));
    }
    
    static void appendVmSelectMessage(String s, String s2) {
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.vmselect", new Object[] { s, s2 }));
    }
    
    static void appendVmSynonymMessage(String s, String s2) {
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.hotspot", new Object[] { s, s2 }));
    }
    
    static void appendVmErgoMessage(boolean b, String s) {
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.ergo.message1", new Object[] { s }));
        LauncherHelper.outBuf = (b ? LauncherHelper.outBuf.append(",\n" + getLocalizedMessage("java.launcher.ergo.message2", new Object[0]) + "\n\n") : LauncherHelper.outBuf.append(".\n\n"));
    }
    
    static void printHelpMessage(boolean b) {
        initOutput(b);
        LauncherHelper.outBuf = LauncherHelper.outBuf.append(getLocalizedMessage("java.launcher.opt.footer", new Object[] { File.pathSeparator }));
        LauncherHelper.ostream.println(LauncherHelper.outBuf.toString());
    }
    
    static void printXUsageMessage(boolean b) {
        initOutput(b);
        LauncherHelper.ostream.println(getLocalizedMessage("java.launcher.X.usage", new Object[] { File.pathSeparator }));
        if (System.getProperty("os.name").contains("OS X")) {
            LauncherHelper.ostream.println(getLocalizedMessage("java.launcher.X.macosx.usage", new Object[] { File.pathSeparator }));
        }
    }
    
    static void initOutput(boolean b) {
        LauncherHelper.ostream = (b ? System.err : System.out);
    }
    
    static String getMainClassFromJar(String name) {
        try (final JarFile jarFile = new JarFile(name)) {
            Manifest manifest = jarFile.getManifest();
            if (manifest == null) {
                abort(null, "java.launcher.jar.error2", new Object[] { name });
            }
            Attributes mainAttributes = manifest.getMainAttributes();
            if (mainAttributes == null) {
                abort(null, "java.launcher.jar.error3", new Object[] { name });
            }
            String value = mainAttributes.getValue("Main-Class");
            if (value == null) {
                abort(null, "java.launcher.jar.error3", new Object[] { name });
            }
            if (mainAttributes.containsKey(new Attributes.Name("JavaFX-Application-Class"))) {
                return LauncherHelper.FXHelper.class.getName();
            }
            else {
                return value.trim();
            }
        }
        catch (IOException ex) {
            abort(ex, "java.launcher.jar.error1", new Object[] { name });
            return null;
        }
    }
    
    static void abort(Throwable t, String s, Object... array) {
        if (s != null) {
            LauncherHelper.ostream.println(getLocalizedMessage(s, array));
        }
        if (LauncherHelper.trace) {
            if (t != null) {
                t.printStackTrace();
            }
            else {
                Thread.dumpStack();
            }
        }
        System.exit(1);
    }
    
    public static Class<?> checkAndLoadMain(boolean b, int i, String s) {
        initOutput(b);
        String mainClassFromJar;
        switch (i) {
            case 1: {
                mainClassFromJar = s;
                break;
            }
            case 2: {
                mainClassFromJar = getMainClassFromJar(s);
                break;
            }
            default: {
                throw new InternalError("" + i + ": Unknown launch mode");
            }
        }
        String replace = mainClassFromJar.replace('/', '.');
        Class<Object> appClass = null;
        try {
            appClass = LauncherHelper.scloader.loadClass(replace);
        }
        catch (NoClassDefFoundError | ClassNotFoundException ex) {
            if (System.getProperty("os.name", "").contains("OS X") && Normalizer.isNormalized(replace, Normalizer.Form.NFD)) {
                try {
                    appClass = LauncherHelper.scloader.loadClass(Normalizer.normalize(replace, Normalizer.Form.NFC));
                }
                catch (NoClassDefFoundError | ClassNotFoundException ex2) {
                    abort(ex, "java.launcher.cls.error1", new Object[] { replace });
                }
            }
            else {
                abort(ex, "java.launcher.cls.error1", new Object[] { replace });
            }
        }
        LauncherHelper.appClass = appClass;
        if (appClass.equals(LauncherHelper.FXHelper.class) || LauncherHelper.FXHelper.access$100(appClass)) {
            LauncherHelper.FXHelper.access$200(s, i);
            return LauncherHelper.FXHelper.class;
        }
        validateMainClass(appClass);
        return appClass;
    }
    
    public static Class<?> getApplicationClass() {
        return LauncherHelper.appClass;
    }
    
    static void validateMainClass(Class<?> clazz) {
        Method method;
        try {
            method = clazz.getMethod("main", new Class[] { String[].class });
        }
        catch (NoSuchMethodException ex) {
            abort(null, "java.launcher.cls.error4", new Object[] { clazz.getName(), "javafx.application.Application" });
            return;
        }
        if (!Modifier.isStatic(method.getModifiers())) {
            abort(null, "java.launcher.cls.error2", new Object[] { "static", method.getDeclaringClass().getName() });
        }
        if (method.getReturnType() != Void.TYPE) {
            abort(null, "java.launcher.cls.error3", new Object[] { method.getDeclaringClass().getName() });
        }
    }
    
    static String makePlatformString(boolean b, byte[] array) {
        initOutput(b);
        if (LauncherHelper.encoding == null) {
            LauncherHelper.encoding = System.getProperty("sun.jnu.encoding");
            LauncherHelper.isCharsetSupported = Charset.isSupported(LauncherHelper.encoding);
        }
        try {
            return LauncherHelper.isCharsetSupported ? new String(array, LauncherHelper.encoding) : new String(array);
        }
        catch (UnsupportedEncodingException ex) {
            abort(ex, null, new Object[0]);
            return null;
        }
    }
    
    static String[] expandArgs(String[] array) {
        ArrayList<LauncherHelper.StdArg> list = new ArrayList();
        for (int length = array.length, i = 0; i < length; ++i) {
            list.add(new LauncherHelper.StdArg(array[i]));
        }
        return expandArgs(list);
    }
    
    static String[] expandArgs(List<LauncherHelper.StdArg> list) {
        ArrayList list2 = new ArrayList();
        if (LauncherHelper.trace) {
            System.err.println("Incoming arguments:");
        }
        for (LauncherHelper.StdArg stdArg : list) {
            if (LauncherHelper.trace) {
                System.err.println(stdArg);
            }
            if (stdArg.needsExpansion) {
                File o = new File(stdArg.arg);
                File parentFile = o.getParentFile();
                String name = o.getName();
                if (parentFile == null) {
                    parentFile = new File(".");
                }
                try (final DirectoryStream directoryStream = Files.newDirectoryStream(parentFile.toPath(), name)) {
                    int n = 0;
                    for (Iterator iterator2 = directoryStream.iterator(); iterator2.hasNext(); ++n) {
                        list2.add(((Path)iterator2.next()).normalize().toString());
                    }
                    if (n == 0) {
                        list2.add(stdArg.arg);
                    }
                    if (directoryStream != null) {
                        Throwable t;
                        if (t != null) {
                            try {
                                directoryStream.close();
                            }
                            catch (Throwable exception) {
                                t.addSuppressed(exception);
                            }
                        }
                        else {
                            directoryStream.close();
                        }
                    }
                    else {
                        continue;
                    }
                }
                catch (Exception obj) {
                    list2.add(stdArg.arg);
                    if (LauncherHelper.trace) {
                        System.err.println("Warning: passing argument as-is " + stdArg);
                        System.err.print(obj);
                    }
                    else {
                        continue;
                    }
                }
            }
            else {
                list2.add(stdArg.arg);
            }
        }
        String[] a = new String[list2.size()];
        list2.toArray(a);
        if (LauncherHelper.trace) {
            System.err.println("Expanded arguments:");
            for (int length = a.length, i = 0; i < length; ++i) {
                System.err.println(a[i]);
            }
            return a;
        }
        return a;
    }
    
    static {
        LauncherHelper.outBuf = new StringBuilder();
        trace = (VM.getSavedProperty("sun.java.launcher.diag") != null);
        scloader = ClassLoader.getSystemClassLoader();
        LauncherHelper.encoding = null;
        LauncherHelper.isCharsetSupported = false;
    }
    
    private static class ResourceBundleHolder
    {
        private static final ResourceBundle RB;
        
        static {
            RB = ResourceBundle.getBundle("sun.launcher.resources.launcher");
        }
    }
    
    private enum SizePrefix
    {
        KILO(1024L, "K"), 
        MEGA(1048576L, "M"), 
        GIGA(1073741824L, "G"), 
        TERA(1099511627776L, "T");
        
        long size;
        String abbrev;
        
        private SizePrefix(long size, String abbrev) {
            this.size = size;
            this.abbrev = abbrev;
        }
        
        private static String scale(long val, LauncherHelper.SizePrefix sizePrefix) {
            return BigDecimal.valueOf(val).divide(BigDecimal.valueOf(sizePrefix.size), 2, RoundingMode.HALF_EVEN).toPlainString() + sizePrefix.abbrev;
        }
        
        static String scaleValue(long n) {
            if (n < LauncherHelper.SizePrefix.MEGA.size) {
                return scale(n, LauncherHelper.SizePrefix.KILO);
            }
            if (n < LauncherHelper.SizePrefix.GIGA.size) {
                return scale(n, LauncherHelper.SizePrefix.MEGA);
            }
            if (n < LauncherHelper.SizePrefix.TERA.size) {
                return scale(n, LauncherHelper.SizePrefix.GIGA);
            }
            return scale(n, LauncherHelper.SizePrefix.TERA);
        }
    }
    
    private static class StdArg
    {
        final String arg;
        final boolean needsExpansion;
        
        StdArg(String arg, boolean needsExpansion) {
            this.arg = arg;
            this.needsExpansion = needsExpansion;
        }
        
        StdArg(String s) {
            this.arg = s.substring(1);
            this.needsExpansion = (s.charAt(0) == 'T');
        }
        
        @Override
        public String toString() {
            return "StdArg{arg=" + this.arg + ", needsExpansion=" + this.needsExpansion + 125;
        }
    }
    
    static final class FXHelper
    {
        private static final String JAVAFX_APPLICATION_MARKER = "JavaFX-Application-Class";
        private static final String JAVAFX_APPLICATION_CLASS_NAME = "javafx.application.Application";
        private static final String JAVAFX_LAUNCHER_CLASS_NAME = "com.sun.javafx.application.LauncherImpl";
        private static final String JAVAFX_LAUNCH_MODE_CLASS = "LM_CLASS";
        private static final String JAVAFX_LAUNCH_MODE_JAR = "LM_JAR";
        private static String fxLaunchName;
        private static String fxLaunchMode;
        private static Class<?> fxLauncherClass;
        private static Method fxLauncherMethod;
        
        private static void setFXLaunchParameters(String fxLaunchName, int i) {
            try {
                LauncherHelper.FXHelper.fxLauncherClass = LauncherHelper.scloader.loadClass("com.sun.javafx.application.LauncherImpl");
                LauncherHelper.FXHelper.fxLauncherMethod = LauncherHelper.FXHelper.fxLauncherClass.getMethod("launchApplication", new Class[] { String.class, String.class, String[].class });
                if (!Modifier.isStatic(LauncherHelper.FXHelper.fxLauncherMethod.getModifiers())) {
                    LauncherHelper.abort(null, "java.launcher.javafx.error1", new Object[0]);
                }
                if (LauncherHelper.FXHelper.fxLauncherMethod.getReturnType() != Void.TYPE) {
                    LauncherHelper.abort(null, "java.launcher.javafx.error1", new Object[0]);
                }
            }
            catch (ClassNotFoundException | NoSuchMethodException ex) {
                LauncherHelper.abort(ex, "java.launcher.cls.error5", new Object[] { ex });
            }
            LauncherHelper.FXHelper.fxLaunchName = fxLaunchName;
            switch (i) {
                case 1: {
                    LauncherHelper.FXHelper.fxLaunchMode = "LM_CLASS";
                    break;
                }
                case 2: {
                    LauncherHelper.FXHelper.fxLaunchMode = "LM_JAR";
                    break;
                }
                default: {
                    throw new InternalError(i + ": Unknown launch mode");
                }
            }
        }
        
        private static boolean doesExtendFXApplication(Class<?> clazz) {
            Class<Object> clazz2 = clazz.getSuperclass();
            while (clazz2 != null) {
                if (clazz2.getName().equals("javafx.application.Application")) {
                    return true;
                }
                clazz2 = clazz2.getSuperclass();
            }
            return false;
        }
        
        public static void main(String... array) throws Exception {
            if (LauncherHelper.FXHelper.fxLauncherMethod == null || LauncherHelper.FXHelper.fxLaunchMode == null || LauncherHelper.FXHelper.fxLaunchName == null) {
                throw new RuntimeException("Invalid JavaFX launch parameters");
            }
            LauncherHelper.FXHelper.fxLauncherMethod.invoke(null, new Object[] { LauncherHelper.FXHelper.fxLaunchName, LauncherHelper.FXHelper.fxLaunchMode, array });
            return;
        }
        
        static boolean access$100(Class clazz) {
            return doesExtendFXApplication(clazz);
        }
        
        static void access$200(String s, int n) {
            setFXLaunchParameters(s, n);
        }
        
        static {
            LauncherHelper.FXHelper.fxLaunchName = null;
            LauncherHelper.FXHelper.fxLaunchMode = null;
            LauncherHelper.FXHelper.fxLauncherClass = null;
            LauncherHelper.FXHelper.fxLauncherMethod = null;
        }
    }
}
